@@ -81,7 +81,7 @@ class Transaction(Resource):
         print(result.transaction.amount)
         print(result.transaction.order_id)
 
-    For more information on Transactions, see https://developers.braintreepayments.com/ios+python/reference/request/transaction/sale
+    For more information on Transactions, see https://developers.braintreepayments.com/reference/request/transaction/sale/python
 
     """
 
@@ -507,7 +507,12 @@ class Transaction(Resource):
                             "points",
                             "currency_amount",
                             "currency_iso_code"
-                        ]
+                        ],
+                        "venmo_merchant_data": [
+                            "venmo_merchant_public_id",
+                            "originating_transaction_id",
+                            "originating_merchant_id"
+                        ],
                     },
                 ]
             },
